@@ -67,56 +67,16 @@ impl TreeSitterParser {
 
 fn main() {
     let parsers = vec![
-        TreeSitterParser {
-            name: "tree-sitter-ada",
-            src_dir: "vendored_parsers/tree-sitter-ada-src",
-            extra_files: vec![],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-clojure",
-            src_dir: "vendored_parsers/tree-sitter-clojure-src",
-            extra_files: vec![],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-cmake",
-            src_dir: "vendored_parsers/tree-sitter-cmake-src",
-            extra_files: vec!["scanner.c"],
-        },
         TreeSitterParser {
             name: "tree-sitter-commonlisp",
             src_dir: "vendored_parsers/tree-sitter-commonlisp-src",
             extra_files: vec![],
         },
-        TreeSitterParser {
-            name: "tree-sitter-dart",
-            src_dir: "vendored_parsers/tree-sitter-dart-src",
-            extra_files: vec!["scanner.c"],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-devicetree",
-            src_dir: "vendored_parsers/tree-sitter-devicetree-src",
-            extra_files: vec![],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-elisp",
-            src_dir: "vendored_parsers/tree-sitter-elisp-src",
-            extra_files: vec![],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-elm",
-            src_dir: "vendored_parsers/tree-sitter-elm-src",
-            extra_files: vec!["scanner.c"],
-        },
         TreeSitterParser {
             name: "tree-sitter-elvish",
             src_dir: "vendored_parsers/tree-sitter-elvish-src",
             extra_files: vec![],
         },
-        TreeSitterParser {
-            name: "tree-sitter-gleam",
-            src_dir: "vendored_parsers/tree-sitter-gleam-src",
-            extra_files: vec!["scanner.c"],
-        },
         TreeSitterParser {
             name: "tree-sitter-hack",
             src_dir: "vendored_parsers/tree-sitter-hack-src",
@@ -127,11 +87,6 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-hare-src",
             extra_files: vec![],
         },
-        TreeSitterParser {
-            name: "tree-sitter-hcl",
-            src_dir: "vendored_parsers/tree-sitter-hcl-src",
-            extra_files: vec!["scanner.cc"],
-        },
         TreeSitterParser {
             name: "tree-sitter-janet-simple",
             src_dir: "vendored_parsers/tree-sitter-janet-simple-src",
@@ -147,61 +102,21 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-latex-src",
             extra_files: vec!["scanner.c"],
         },
-        TreeSitterParser {
-            name: "tree-sitter-newick",
-            src_dir: "vendored_parsers/tree-sitter-newick-src",
-            extra_files: vec![],
-        },
         TreeSitterParser {
             name: "tree-sitter-perl",
             src_dir: "vendored_parsers/tree-sitter-perl-src",
             extra_files: vec!["scanner.c"],
         },
-        TreeSitterParser {
-            name: "tree-sitter-qmljs",
-            src_dir: "vendored_parsers/tree-sitter-qmljs-src",
-            extra_files: vec!["scanner.c"],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-r",
-            src_dir: "vendored_parsers/tree-sitter-r-src",
-            extra_files: vec!["scanner.cc"],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-racket",
-            src_dir: "vendored_parsers/tree-sitter-racket-src",
-            extra_files: vec!["scanner.c"],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-scheme",
-            src_dir: "vendored_parsers/tree-sitter-scheme-src",
-            extra_files: vec![],
-        },
         TreeSitterParser {
             name: "tree-sitter-scss",
             src_dir: "vendored_parsers/tree-sitter-scss-src",
             extra_files: vec!["scanner.c"],
         },
-        TreeSitterParser {
-            name: "tree-sitter-sfapex",
-            src_dir: "vendored_parsers/tree-sitter-sfapex-src",
-            extra_files: vec![],
-        },
         TreeSitterParser {
             name: "tree-sitter-smali",
             src_dir: "vendored_parsers/tree-sitter-smali-src",
             extra_files: vec!["scanner.c"],
         },
-        TreeSitterParser {
-            name: "tree-sitter-solidity",
-            src_dir: "vendored_parsers/tree-sitter-solidity-src",
-            extra_files: vec![],
-        },
-        TreeSitterParser {
-            name: "tree-sitter-sql",
-            src_dir: "vendored_parsers/tree-sitter-sql-src",
-            extra_files: vec!["scanner.cc"],
-        },
         TreeSitterParser {
             name: "tree-sitter-vhdl",
             src_dir: "vendored_parsers/tree-sitter-vhdl-src",
